@@ -4,7 +4,7 @@ from .message import Message
 
 class Channel:
     def __init__(self, id):
-        request = Wrapper.sendDiscordRequest(method="get", urlAddon=f"channels/{id}", headers={}, payload={})
+        request = Wrapper.sendDiscordRequest(method="get", urlAddon=f"channels/{id}", headers={}, payload={}).json()
         self.id = id
         self.name = request["name"]
         self.topic = request["topic"]
@@ -18,5 +18,5 @@ class Channel:
         if embed != None:
             data["embed"] = embed
 
-        request = Wrapper.sendDiscordRequest(method="post", urlAddon=url, headers={}, payload=data)
+        request = Wrapper.sendDiscordRequest(method="post", urlAddon=url, headers={}, payload=data).json()
         return Message(request["id"], request["content"], request["embeds"], request["channel_id"], request["author"])
\ No newline at end of file
