@@ -12,5 +12,5 @@ class Message():
         self.author = author
     def edit(self, content=None, embed=None):
         url = "channels/"+str(self.channel.id)+"/messages/"+str(self.id)
-        request = Wrapper.sendDiscordRequest(method="patch", urlAddon=url, headers={}, payload={"content": content, "embed": embed})
+        request = Wrapper.sendDiscordRequest(method="patch", urlAddon=url, headers={}, payload={"content": content, "embed": embed}).json()
         return Message(request["id"], request["content"], request["embeds"], request["channel_id"], request["author"])        
\ No newline at end of file
